@@ -27,6 +27,10 @@ from pipeline.engine.models import FunctionSwitch
 from pipeline.models import PipelineInstance
 from pipeline.parser.context import get_pipeline_context
 from pipeline.eri.runtime import BambooDjangoRuntime
+from pipeline.contrib.periodic_task.context import (
+    get_periodic_task_root_pipeline_context,
+    get_periodic_task_subprocess_context,
+)
 
 logger = logging.getLogger("celery")
 
@@ -125,13 +129,19 @@ def bamboo_engine_periodic_task_start(*args, **kwargs):
             is_started=True,
             executor=periodic_task.creator,
         )
+        root_pipeline_data = get_pipeline_context(
+            instance, obj_type="instance", data_type="data", username=periodic_task.creator
+        )
+        root_pipeline_context = get_periodic_task_root_pipeline_context(root_pipeline_data)
+        subprocess_context = get_periodic_task_subprocess_context(root_pipeline_data)
         result = bamboo_engine_api.run_pipeline(
             runtime=BambooDjangoRuntime(),
             pipeline=pipeline,
-            root_pipeline_data=get_pipeline_context(
-                instance, obj_type="instance", data_type="data", username=periodic_task.creator
-            ),
+            root_pipeline_data=root_pipeline_data,
+            root_pipeline_context=root_pipeline_context,
+            subprocess_context=subprocess_context,
             queue=periodic_task.queue,
+            cycle_tolerate=True,
         )
     except Exception:
         et = traceback.format_exc()
