@@ -79,9 +79,10 @@ def recursive_collect_components(activities, status_tree, instance_id, stack=Non
                         if engine_ver == 1:
                             history_list = pipeline_api.get_activity_histories(act_id)
                         else:
-                            history_list = bamboo_engine_api.get_node_short_histories(
+                            history_list_result = bamboo_engine_api.get_node_short_histories(
                                 runtime=BambooDjangoRuntime(), node_id=act_id
                             )
+                            history_list = history_list_result.data if history_list_result.result else []
 
                         for history in history_list:
                             create_kwargs.update(
