@@ -13,12 +13,13 @@ specific language governing permissions and limitations under the License.
 
 import logging
 
+from pipeline.core.data import var
 from pipeline.core.flow.event import EmptyStartEvent
 from pipeline.engine.models import Status
 
 from .base import FlowElementHandler
 
-logger = logging.getLogger("celery")
+logger = logging.getLogger("pipeline_engine")
 
 __all__ = ["EmptyStartEventHandler"]
 
@@ -28,6 +29,17 @@ class EmptyStartEventHandler(FlowElementHandler):
     def element_cls():
         return EmptyStartEvent
 
+    @staticmethod
+    def _hydrate(value):
+        return value.get() if issubclass(value.__class__, var.Variable) else value
+
     def handle(self, process, element, status):
+        # 进行变量预渲染
+        if hasattr(element.data, "inputs"):
+            for pre_render_key in element.data.inputs.get("pre_render_keys", []):
+                context_variables = process.top_pipeline.context.variables
+                if pre_render_key in context_variables:
+                    context_variables[pre_render_key] = self._hydrate(context_variables[pre_render_key])
+
         Status.objects.finish(element)
         return self.HandleResult(next_node=element.next(), should_return=False, should_sleep=False)
