@@ -107,10 +107,6 @@ class ProcessManager(models.Manager):
         :return:
         """
         # init runtime info
-
-        # clear parent's change
-        parent.top_pipeline.context.clear_change_keys()
-
         pipeline_stack = Stack([parent.top_pipeline])
         root_pipeline_shell = parent.root_pipeline.shell()
         snapshot = ProcessSnapshot.objects.create_snapshot(
@@ -123,6 +119,8 @@ class ProcessManager(models.Manager):
         snapshot.refresh_from_db()
         snapshot.prune_top_pipeline(current_node_id, destination_id)
         snapshot.save()
+        # clear parent's change
+        snapshot.pipeline_stack.top().context.clear_change_keys()
 
         child = self.create(
             id=node_uniqid(),
@@ -211,7 +209,7 @@ class PipelineProcess(models.Model):
     root_pipeline_id = models.CharField(_("根 pipeline 的 ID"), max_length=32, db_index=True)
     current_node_id = models.CharField(_("当前推进到的节点的 ID"), max_length=32, default="", db_index=True)
     destination_id = models.CharField(_("遇到该 ID 的节点就停止推进"), max_length=32, default="")
-    parent_id = models.CharField(_("父 process 的 ID"), max_length=32, default="")
+    parent_id = models.CharField(_("父 process 的 ID"), max_length=32, default="", db_index=True)
     ack_num = models.IntegerField(_("收到子节点 ACK 的数量"), default=0)
     need_ack = models.IntegerField(_("需要收到的子节点 ACK 的数量"), default=-1)
     is_alive = models.BooleanField(_("该 process 是否还有效"), default=True, db_index=True)
